@@ -23,7 +23,7 @@ pub fn create_default_shaders<P: AsRef<Path>>(name: P) -> std::io::Result<()> {
 
 const FRAG_SHADER: &str = "#version 460
 
-// In the beginning, colours never existed. There's nothing that can be done before you...
+// In the beginning, colours never existed. There's nothing that was done before you...
 
 #include <prelude.glsl>
 
@@ -40,8 +40,6 @@ layout(set = 1, binding = 0) uniform sampler tex_sampler;
 #define Tuv(tex) (T(tex, in_uv))
 #define T_off(tex, off) (T(tex, vec2(in_uv.x + off.x, -(in_uv.y + off.y))))
 
-layout(set = 1, binding = 0) uniform sampler1D fft_texture;
-
 layout(std430, push_constant) uniform PushConstant {
     vec3 pos;
     float time;
@@ -53,32 +51,10 @@ layout(std430, push_constant) uniform PushConstant {
     float record_period;
 } pc;
 
-float worldSDF(in vec3 pos) {
-	float res = -1.0;
-	res = sphereSDF(pos);
-
-	return res;
-}
-
 void main() {
     vec2 uv = (in_uv + -0.5) * 2.0 * vec2(pc.resolution.x / pc.resolution.y, 1);
 
-	vec3 O = vec3(0.0, 0.0, 3.0);
-	vec3 D = normalize(vec3(uv, -2.));
-
-	vec2 path = ray_march(O, D);
-	vec3 normal = wnormal(O);
-	vec3 at = O + path.x * D;
-
-	float r = 2.0;
-	vec2 l = r * vec2(cos(pc.time), sin(pc.time));
-	vec3 l_pos = vec3(l.x, 3.0, l.y + 2.0);
-
-	vec3 l_col = vec3(1.0, 1.0, 0.7);
-    vec3 diffuse = vec3(0.5, 0.5, 0.5);
-	vec3 dlight = enlight(at, wnormal(at), diffuse, l_col, l_pos);
-
-    vec3 col = dlight * 10.;
+    vec3 col = vec3(uv, 1.);
     out_color = vec4(col, 1.0);
 }";
 
@@ -124,8 +100,6 @@ layout (binding = 2, rgba8) uniform image2D dummy_texture;
 layout (binding = 3, rgba32f) uniform image2D float_texture1;
 layout (binding = 4, rgba32f) uniform image2D float_texture2;
 
-layout(set = 1, binding = 0) uniform sampler1D fft_texture;
-
 void main() {
     if (gl_GlobalInvocationID.x >= pc.resolution.x ||
         gl_GlobalInvocationID.y >= pc.resolution.y) {
@@ -133,20 +107,38 @@ void main() {
     }
 }";
 
-const PRELUDE: &str = "#define PI 3.14159265359
-#define TWOPI 6.28318530718
+const PRELUDE: &str = "
+const float PI = acos(-1.);
+const float TAU = 2. * PI;
 
-const vec3 EPS = vec3(0., 0.01, 0.001);
-const float HIT_DIST = EPS.y;
-const int MAX_STEPS = 100;
-const float MISS_DIST = 10.0;
-
-const float WIDTH = 2.0;
 const float HALF_WIDTH = 1.0;
 
+vec4 ASSERT_COL = vec4(0.);
+void assert(bool cond, int v) {
+    if (!(cond)) {
+        if      (v == 0) ASSERT_COL.x = -1.0;
+        else if (v == 1) ASSERT_COL.y = -1.0;
+        else if (v == 2) ASSERT_COL.z = -1.0;
+        else             ASSERT_COL.w = -1.0;
+    }
+}
+void assert(bool cond) { assert(cond, 0); }
+#define catch_assert(out)                                   \
+    if (ASSERT_COL.x < 0.0) out = vec4(1.0, 0.0, 0.0, 1.0); \
+    if (ASSERT_COL.y < 0.0) out = vec4(0.0, 1.0, 0.0, 1.0); \
+    if (ASSERT_COL.z < 0.0) out = vec4(0.0, 0.0, 1.0, 1.0); \
+    if (ASSERT_COL.w < 0.0) out = vec4(1.0, 1.0, 0.0, 1.0);
+
+#define AAstep(thre, val) \
+    smoothstep(-.7, .7, (val - thre) / min(0.07, fwidth(val - thre)))
+
 float worldSDF(vec3 rayPos);
 
 vec2 ray_march(vec3 rayPos, vec3 rayDir) {
+    const vec3 EPS = vec3(0., 0.001, 0.0001);
+    const float HIT_DIST = EPS.y;
+    const int MAX_STEPS = 100;
+    const float MISS_DIST = 10.0;
     float dist = 0.0;
 
     for(int i = 0; i < MAX_STEPS; i++) {
@@ -224,7 +216,8 @@ vec3 enlight(in vec3 at, vec3 normal, vec3 diffuse, vec3 l_color, vec3 l_pos) {
 }
 
 vec3 wnormal(in vec3 p) {
-  return normalize(vec3(worldSDF(p + EPS.yxx) - worldSDF(p - EPS.yxx),
+    const vec3 EPS = vec3(0., 0.01, 0.0001);
+    return normalize(vec3(worldSDF(p + EPS.yxx) - worldSDF(p - EPS.yxx),
                         worldSDF(p + EPS.xyx) - worldSDF(p - EPS.xyx),
                         worldSDF(p + EPS.xxy) - worldSDF(p - EPS.xxy)));
 }";
